@@ -3,28 +3,24 @@
 #![doc(hidden)]
 
 // Select the correct back-end.
-#[cfg(not(feature = "compact"))]
-use crate::algorithm::{algorithm_complete, algorithm_partial};
-#[cfg(feature = "compact")]
-use crate::compact::{algorithm_complete, algorithm_partial};
-
-use lexical_util::num::{Integer, UnsignedInteger};
+use lexical_util::num::Integer;
 use lexical_util::result::Result;
 
+use crate::algorithm::{algorithm_complete, algorithm_partial};
+use crate::Options;
+
 /// Parse integer trait, implemented in terms of the optimized back-end.
 pub trait ParseInteger: Integer {
     /// Forward complete parser parameters to the backend.
     #[cfg_attr(not(feature = "compact"), inline(always))]
-    fn parse_complete<Unsigned: UnsignedInteger, const FORMAT: u128>(bytes: &[u8]) -> Result<Self> {
-        algorithm_complete::<_, Unsigned, { FORMAT }>(bytes)
+    fn parse_complete<const FORMAT: u128>(bytes: &[u8], options: &Options) -> Result<Self> {
+        algorithm_complete::<_, { FORMAT }>(bytes, options)
     }
 
     /// Forward partial parser parameters to the backend.
     #[cfg_attr(not(feature = "compact"), inline(always))]
-    fn parse_partial<Unsigned: UnsignedInteger, const FORMAT: u128>(
-        bytes: &[u8],
-    ) -> Result<(Self, usize)> {
-        algorithm_partial::<_, Unsigned, { FORMAT }>(bytes)
+    fn parse_partial<const FORMAT: u128>(bytes: &[u8], options: &Options) -> Result<(Self, usize)> {
+        algorithm_partial::<_, { FORMAT }>(bytes, options)
     }
 }
 
