@@ -1,4 +1,3 @@
-#[cfg(feature = "power-of-two")]
 mod util;
 
 use lexical_parse_integer::{FromLexical, FromLexicalWithOptions, Options};
@@ -10,6 +9,8 @@ use proptest::prelude::*;
 #[cfg(feature = "power-of-two")]
 use util::from_radix;
 
+use crate::util::default_proptest_config;
+
 #[test]
 fn u8_decimal_test() {
     assert_eq!(Ok(0), u8::from_lexical(b"0"));
@@ -96,7 +97,7 @@ fn i64_decimal_test() {
 
     // Add tests discovered via fuzzing. This won't necessarily be the
     // proper index, since we use multi-digit parsing.
-    assert!(i64::from_lexical(b"406260572150672006000066000000060060007667760000000000000000000+00000006766767766666767665670000000000000000000000666").err().unwrap().is_invalid_digit());
+    assert!(i64::from_lexical(b"406260572150672006000066000000060060007667760000000000000000000+00000006766767766666767665670000000000000000000000666").err().unwrap().is_overflow());
     assert!(i64::from_lexical(b"406260572150672006000066000000060060007667760000000000000000000")
         .err()
         .unwrap()
@@ -141,6 +142,12 @@ fn i128_decimal_test() {
     assert_eq!(Err(Error::InvalidDigit(1)), i128::from_lexical(b"1a"));
 }
 
+#[test]
+fn double_sign_test() {
+    assert_eq!(Err(Error::InvalidDigit(1)), i16::from_lexical(b"+-0000"));
+    assert_eq!(Err(Error::InvalidDigit(1)), i128::from_lexical(b"+-0000"));
+}
+
 #[test]
 fn options_test() {
     let options = Options::new();
@@ -386,7 +393,7 @@ macro_rules! is_underflow {
 }
 
 macro_rules! is_invalid_digit_match {
-    ($result:expr, $p1:pat $(| $prest:pat)*) => {{
+    ($result:expr, $p1:pat_param $(| $prest:pat_param)*) => {{
         let result = $result;
         prop_assert!(result.is_err());
         let err = result.err().unwrap();
@@ -396,8 +403,9 @@ macro_rules! is_invalid_digit_match {
 }
 
 proptest! {
+    #![proptest_config(default_proptest_config())]
+
     #[test]
-    #[cfg_attr(miri, ignore)]
     #[cfg(feature = "power-of-two")]
     fn i32_binary_roundtrip_display_proptest(i in i32::MIN..i32::MAX) {
         let options = Options::new();
@@ -412,361 +420,301 @@ proptest! {
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u8_invalid_proptest(i in r"[+]?[0-9]{2}\D") {
         is_invalid_digit_match!(u8::from_lexical(i.as_bytes()), 2 | 3);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u8_overflow_proptest(i in r"[+]?[1-9][0-9]{3}") {
         is_overflow!(u8::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u8_negative_proptest(i in r"[-][1-9][0-9]{2}") {
         is_invalid_digit!(u8::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u8_double_sign_proptest(i in r"[+]{2}[0-9]{2}") {
         is_invalid_digit_match!(u8::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u8_sign_only_proptest(i in r"[+]") {
         is_empty!(u8::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u8_trailing_digits_proptest(i in r"[+]?[0-9]{2}\D[0-9]{2}") {
         is_invalid_digit_match!(u8::from_lexical(i.as_bytes()), 2 | 3);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i8_invalid_proptest(i in r"[+-]?[0-9]{2}\D") {
         is_invalid_digit_match!(i8::from_lexical(i.as_bytes()), 2 | 3);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i8_overflow_proptest(i in r"[+]?[1-9][0-9]{3}") {
         is_overflow!(i8::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i8_underflow_proptest(i in r"[-][1-9][0-9]{3}") {
         is_underflow!(i8::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i8_double_sign_proptest(i in r"[+-]{2}[0-9]{2}") {
         is_invalid_digit_match!(i8::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i8_sign_only_proptest(i in r"[+-]") {
         is_empty!(i8::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i8_trailing_digits_proptest(i in r"[+-]?[0-9]{2}\D[0-9]{2}") {
         is_invalid_digit_match!(i8::from_lexical(i.as_bytes()), 2 | 3);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u16_invalid_proptest(i in r"[+]?[0-9]{4}\D") {
         is_invalid_digit_match!(u16::from_lexical(i.as_bytes()), 4 | 5);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u16_overflow_proptest(i in r"[+]?[1-9][0-9]{5}") {
         is_overflow!(u16::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u16_negative_proptest(i in r"[-][1-9][0-9]{4}") {
         is_invalid_digit!(u16::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u16_double_sign_proptest(i in r"[+]{2}[0-9]{4}") {
         is_invalid_digit_match!(u16::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u16_sign_only_proptest(i in r"[+]") {
         is_empty!(u16::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u16_trailing_digits_proptest(i in r"[+]?[0-9]{4}\D[0-9]{2}") {
         is_invalid_digit_match!(u16::from_lexical(i.as_bytes()), 4 | 5);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i16_invalid_proptest(i in r"[+-]?[0-9]{4}\D") {
         is_invalid_digit_match!(i16::from_lexical(i.as_bytes()), 4 | 5);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i16_overflow_proptest(i in r"[+]?[1-9][0-9]{5}") {
         is_overflow!(i16::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i16_underflow_proptest(i in r"[-][1-9][0-9]{5}") {
         is_underflow!(i16::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i16_double_sign_proptest(i in r"[+-]{2}[0-9]{4}") {
         is_invalid_digit_match!(i16::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i16_sign_only_proptest(i in r"[+-]") {
         is_empty!(i16::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i16_trailing_digits_proptest(i in r"[+-]?[0-9]{4}\D[0-9]{2}") {
         is_invalid_digit_match!(i16::from_lexical(i.as_bytes()), 4 | 5);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u32_invalid_proptest(i in r"[+]?[0-9]{9}\D") {
         is_invalid_digit_match!(u32::from_lexical(i.as_bytes()), 9 | 10);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u32_overflow_proptest(i in r"[+]?[1-9][0-9]{10}") {
         is_overflow!(u32::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u32_negative_proptest(i in r"[-][1-9][0-9]{9}") {
         is_invalid_digit!(u32::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u32_double_sign_proptest(i in r"[+]{2}[0-9]{9}") {
         is_invalid_digit_match!(u32::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u32_sign_only_proptest(i in r"[+]") {
         is_empty!(u32::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u32_trailing_digits_proptest(i in r"[+]?[0-9]{9}\D[0-9]{2}") {
         is_invalid_digit_match!(u32::from_lexical(i.as_bytes()), 9 | 10);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i32_invalid_proptest(i in r"[+-]?[0-9]{9}\D") {
         is_invalid_digit_match!(i32::from_lexical(i.as_bytes()), 9 | 10);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i32_overflow_proptest(i in r"[+]?[1-9][0-9]{10}") {
         is_overflow!(i32::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i32_underflow_proptest(i in r"-[1-9][0-9]{10}") {
         is_underflow!(i32::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i32_double_sign_proptest(i in r"[+-]{2}[0-9]{9}") {
         is_invalid_digit_match!(i32::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i32_sign_only_proptest(i in r"[+-]") {
         is_empty!(i32::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i32_trailing_digits_proptest(i in r"[+-]?[0-9]{9}\D[0-9]{2}") {
         is_invalid_digit_match!(i32::from_lexical(i.as_bytes()), 9 | 10);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u64_invalid_proptest(i in r"[+]?[0-9]{19}\D") {
         is_invalid_digit_match!(u64::from_lexical(i.as_bytes()), 19 | 20);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u64_overflow_proptest(i in r"[+]?[1-9][0-9]{21}") {
         is_overflow!(u64::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u64_negative_proptest(i in r"[-][1-9][0-9]{21}") {
         is_invalid_digit!(u64::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u64_double_sign_proptest(i in r"[+]{2}[0-9]{19}") {
         is_invalid_digit_match!(u64::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u64_sign_only_proptest(i in r"[+]") {
         is_empty!(u64::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u64_trailing_digits_proptest(i in r"[+]?[0-9]{19}\D[0-9]{2}") {
         is_invalid_digit_match!(u64::from_lexical(i.as_bytes()), 19 | 20);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i64_invalid_proptest(i in r"[+-]?[0-9]{18}\D") {
         is_invalid_digit_match!(i64::from_lexical(i.as_bytes()), 18 | 19);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i64_overflow_proptest(i in r"[+]?[1-9][0-9]{19}") {
         is_overflow!(i64::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i64_underflow_proptest(i in r"-[1-9][0-9]{19}") {
         is_underflow!(i64::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i64_double_sign_proptest(i in r"[+-]{2}[0-9]{18}") {
         is_invalid_digit_match!(i64::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i64_sign_only_proptest(i in r"[+-]") {
         is_empty!(i64::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i64_trailing_digits_proptest(i in r"[+-]?[0-9]{18}\D[0-9]{2}") {
         is_invalid_digit_match!(i64::from_lexical(i.as_bytes()), 18 | 19);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u128_invalid_proptest(i in r"[+]?[0-9]{38}\D") {
         is_invalid_digit_match!(u128::from_lexical(i.as_bytes()), 38 | 39);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u128_overflow_proptest(i in r"[+]?[1-9][0-9]{39}") {
         is_overflow!(u128::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u128_negative_proptest(i in r"[-][1-9][0-9]{39}") {
         is_invalid_digit!(u128::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u128_double_sign_proptest(i in r"[+]{2}[0-9]{38}") {
         is_invalid_digit_match!(u128::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u128_sign_only_proptest(i in r"[+]") {
         is_empty!(u128::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn u128_trailing_digits_proptest(i in r"[+]?[0-9]{38}\D[0-9]{2}") {
         is_invalid_digit_match!(u128::from_lexical(i.as_bytes()), 38 | 39);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i128_invalid_proptest(i in r"[+-]?[0-9]{38}\D") {
         is_invalid_digit_match!(i128::from_lexical(i.as_bytes()), 38 | 39);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i128_overflow_proptest(i in r"[+]?[1-9][0-9]{39}") {
         is_overflow!(i128::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i128_underflow_proptest(i in r"-[1-9][0-9]{39}") {
         is_underflow!(i128::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i128_double_sign_proptest(i in r"[+-]{2}[0-9]{38}") {
         is_invalid_digit_match!(i128::from_lexical(i.as_bytes()), 1);
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i128_sign_only_proptest(i in r"[+-]") {
         is_empty!(i128::from_lexical(i.as_bytes()));
     }
 
     #[test]
-    #[cfg_attr(miri, ignore)]
     fn i128_trailing_digits_proptest(i in r"[+-]?[0-9]{38}\D[0-9]{2}") {
         is_invalid_digit_match!(i128::from_lexical(i.as_bytes()), 38 | 39);
     }
