@@ -4,7 +4,7 @@ use lexical_parse_integer::options::{Options, OptionsBuilder};
 fn options_tests() {
     let builder = OptionsBuilder::new();
     assert!(builder.is_valid());
-    assert!(unsafe { builder.build_unchecked() }.is_valid());
+    assert!(builder.build_unchecked().is_valid());
     assert!(OptionsBuilder::default().is_valid());
 
     let options: Options = Options::new();
